PyXMake Developer Guide: PyXMake.Build.Make.Custom Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Custom Class Reference

Base class for all custom build events inherited from Make. More...

Inheritance diagram for PyXMake.Build.Make.Custom:

## Public Member Functions
def | __init__ (self, args, kwargs)
def | Preprocessing
def | Build (self, cmdstring)
Public Member Functions inherited from PyXMake.Build.Make.Make
def | __init__ (self, BuildID, Srcs, scratch=os.getcwd(), msvsc='vs2015', stype='Fortran', verbose=0, args, kwargs)
def | __getstate__ (self)
def | __setstate__ (self, _dict)
def | AddIncludePath (self, includes)
def | AddDependencyPath (self, dependencies)
def | UseLibraries (self, libs)
def | SourcePath (self, path)
def | OutputPath (self, path, files="")
def | Environment (self, path, script="ifortvars.bat")
def | Preprocessing
def | Build (self, cmdstring)
def | Postprocessing (self, cmdstring='')
def | create (self)

## Public Attributes
| MakeObjectKind
| String identifier of current instance. More...
| exe
| The executable command used in all build events. More...
| buildname
| Immutable settings for Custom object. More...
| temps
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid
| Base string of build object. More...
| srcs
| Source file or folders.
| stype
| Source file type.
| verbose
| Level of verbosity of the current build object. More...
| scrtdir
| Current scratch directory.
| srcdir
| Default search directory for source files. More...
| outdir
| Default search directory for output. More...
| intelpath
| Path to Intel Fortran Compiler (read from Paths.log). More...
| temps
| Tuple of data to be removed after job completion. More...
| incdirs
| List of include directories. More...
| libdirs
| List of library directories. More...
| libs
| List of actual libraries (by name) used during linking. More...
| copyfiles
| List of files to be copied to the output directory after finish. More...
| setarch
| Define the architecture for the build directly by using the keyword argument "arch". More...
| architecture
| Processor architecture.
| iniCompiler
| Executable batch script (including absolute system path) to set up the Intel Fortran Compiler. More...
| msvsc
| Default version of Microsoft visual studio used by the Intel Fortran Compiler. More...
| postcmd
| Post build command. More...
| buildname
| precmd
| Command executed during pre-build event. More...
| compargs
| Command line arguments passed in by the user. More...
| makecmd
| Command executed during build event. More...

## Detailed Description

Base class for all custom build events inherited from Make.

    Inherited class to build projects without any presets.

Definition at line 404 of file Make.py.

## Constructor & Destructor Documentation

## ◆ __init__()

def PyXMake.Build.Make.Custom.__init__ | ( |  | self,
|  |  | args,
|  |  | kwargs
| ) |  |

    Initialization of Custom class object.

Definition at line 408 of file Make.py.

## Member Function Documentation

## ◆ Build()

def PyXMake.Build.Make.Custom.Build | ( |  | self,
|  |  | cmdstring
| ) |  |

    Assemble command string for the main build event.

Definition at line 466 of file Make.py.

## Member Data Documentation

## ◆ buildname

PyXMake.Build.Make.Custom.buildname

Immutable settings for Custom object.

Temporary build name, assembled using BuildID.

Definition at line 421 of file Make.py.

## ◆ compargs

PyXMake.Build.Make.Custom.compargs

Command line arguments passed in by the user.

Definition at line 460 of file Make.py.

## ◆ exe

PyXMake.Build.Make.Custom.exe

The executable command used in all build events.

Definition at line 417 of file Make.py.

## ◆ makecmd

PyXMake.Build.Make.Custom.makecmd

Command executed during build event.

Definition at line 497 of file Make.py.

## ◆ MakeObjectKind

PyXMake.Build.Make.Custom.MakeObjectKind

String identifier of current instance.

Definition at line 414 of file Make.py.

## ◆ precmd

PyXMake.Build.Make.Custom.precmd

Command executed during pre-build event.

Definition at line 457 of file Make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/Build/Make.py